@@ -14,5 +14,5 @@
 HashItem *construct_verb(char const *key, char *rest)
 {
     return hashitem_construct(VOIDPTR, "",
-                    (void *)(*(rest + 1) == 'n'), root_nop);
+                    (void *)(size_t)(*(rest + 1) == 'n'), root_nop);
 }
